==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ca.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactes",
    "Address book name" : "Nom de la llibreta d'adreces",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imatge seleccionada és massa gran (màxim 1MB)",
    "No contacts in here" : "No hi ha contactes",
    "Name" : "Nom",
    "Organization" : "Organització",
    "Title" : "Títol",
    "Add field ..." : "Afegeix camp...",
    "+ New contact" : "+ Contacte nou",
    "No search result for {query}" : "No s'han trobat resultats per {query}",
    "_%n contact_::_%n contacts_" : ["%n contactes","%n contactes"],
    "Post office box" : "Apartat de Correus",
    "Postal code" : "Codi postal",
    "City" : "Ciutat",
    "State or province" : "Estat o província",
    "Country" : "País",
    "Address" : "Adreça",
    "(new group)" : "(grup nou)",
    "Last name" : "Cognom",
    "First name" : "Nom",
    "Additional names" : "Noms addicionals",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "All contacts" : "Tots els contactes",
    "Not grouped" : "Sense grup",
    "New contact" : "Contacte nou",
    "{addressbook} shared by {owner}" : "{addressbook} compartida per {owner}",
    "No contacts in file. Only VCard files are allowed." : "No hi ha contactes a l'arxiu. Només s'accepten arxius en format VCard.",
    "Nickname" : "Sobrenom",
    "Notes" : "Anotacions",
    "Website" : "Pàgina web",
    "Federated Cloud ID" : "ID de núvol federat",
    "Home" : "Casa",
    "Work" : "Feina",
    "Other" : "Un altre",
    "Groups" : "Grups",
    "Birthday" : "Aniversari",
    "Date of death" : "Data de la mort",
    "Email" : "Correu electrònic",
    "Instant messaging" : "Missatgeria instantània",
    "Phone" : "Telèfon",
    "Mobile" : "Mòbil",
    "Fax" : "Fax",
    "Fax home" : "Fax (casa)",
    "Fax work" : "Fax (feina)",
    "Pager" : "Paginador",
    "Voice" : "Veu",
    "Social network" : "Xarxa social",
    "Settings" : "configuració"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ca.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactes",
    "Download" : "Descàrrega",
    "Delete Addressbook" : "Elimina llibreta d'adreces",
    "Delete" : "Esborra",
    "can edit" : "pot editar",
    "Address book name" : "Nom de la llibreta d'adreces",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "La imatge seleccionada és massa gran (màxim 1MB)",
    "No contacts in here" : "No hi ha contactes",
    "Name" : "Nom",
    "Organization" : "Organització",
    "Title" : "Títol",
    "Add field ..." : "Afegeix camp...",
    "No search result for {query}" : "No s'han trobat resultats per {query}",
    "_%n contact_::_%n contacts_" : ["%n contactes","%n contactes"],
    "Post office box" : "Apartat de Correus",
    "Postal code" : "Codi postal",
    "City" : "Ciutat",
    "State or province" : "Estat o província",
    "Country" : "País",
    "Address" : "Adreça",
    "(new group)" : "(grup nou)",
    "Last name" : "Cognom",
    "First name" : "Nom",
    "Additional names" : "Noms addicionals",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "All contacts" : "Tots els contactes",
    "Not grouped" : "Sense grup",
    "New contact" : "Contacte nou",
    "{addressbook} shared by {owner}" : "{addressbook} compartida per {owner}",
    "Contact could not be created." : "No s'ha pogut crear el contacte.",
    "No contacts in file. Only VCard files are allowed." : "No hi ha contactes a l'arxiu. Només s'accepten arxius en format VCard.",
    "Nickname" : "Sobrenom",
    "Detailed name" : "Nom complet",
    "Notes" : "Anotacions",
    "Website" : "Pàgina web",
    "Federated Cloud ID" : "ID de núvol federat",
    "Home" : "Casa",
    "Work" : "Feina",
    "Other" : "Un altre",
    "Groups" : "Grups",
    "Birthday" : "Aniversari",
    "Anniversary" : "Aniversari",
    "Date of death" : "Data de la mort",
    "Email" : "Correu electrònic",
    "Instant messaging" : "Missatgeria instantània",
    "Phone" : "Telèfon",
    "Mobile" : "Mòbil",
    "Fax" : "Fax",
    "Fax home" : "Fax (casa)",
    "Fax work" : "Fax (feina)",
    "Pager" : "Paginador",
    "Voice" : "Veu",
    "Social network" : "Xarxa social",
    "Settings" : "configuració"
},
"nplurals=2; plural=(n != 1);");
